@@ -32,26 +32,21 @@ def get_text(images: list, text_only=False, dist_dir='./output'):
         bboxes = localization_model.get_text_localization(original_image,
                                                           weights=os.path.join(base_path, 'data', 'weights',
                                                                                'localization_weights.h5'))
+
         for index, bbox in enumerate(bboxes):
             filename = os.path.basename(image_path)
             bbox = np.reshape(bbox, newshape=(-1, 8)).astype(np.int)[0]
             clipped_image = original_image[bbox[1]:bbox[5], bbox[0]:bbox[4]]
-            print(os.path.join(dist_dir, f'{filename}_{index}.jpg'))
-            cv2.imwrite(os.path.join(dist_dir, f'{filename}_{index}.jpg'), clipped_image)
-            try:
+            if clipped_image.shape[0] > 1 and clipped_image.shape[1] > 1:
                 if not text_only:
-                    original_image = cv2.rectangle(original_image, (bbox[0], bbox[1]), (bbox[4], bbox[5]), (255, 0, 0),
-                                                   2,
-                                                   1)
-                    cv2.imwrite(os.path.join(dist_dir, f'{filename}.jpg'), original_image)
+                    cv2.imwrite(os.path.join(dist_dir, f'{filename}_{index}.jpg'), clipped_image)
+
                 text = recognition_model.get_text(clipped_image,
                                                   weights=os.path.join(base_path, 'data', 'weights',
                                                                        'recognition_weights.h5'),
                                                   label=os.path.join(base_path, 'data', 'label.txt'))
                 with open(os.path.join(dist_dir, f'{filename}_{index}.txt'), 'w', encoding='utf-8') as f:
                     f.write(text)
-            except cv2.Error:
-                continue
 
 
 if __name__ == '__main__':
